@@ -5,17 +5,17 @@ package Chart::GGPlot::Backend::Plotly;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 with qw(Chart::GGPlot::Backend);
 
-use Chart::Plotly qw(show_plot);
+use Chart::Plotly 0.023 qw(show_plot);
 use Chart::Plotly::Plot;
-use Chart::Plotly::Image;
+use Chart::Plotly::Image::Orca;
 
 use Data::Munge qw(elem);
 use JSON;
-use List::AllUtils qw(pairmap pairwise uniq);
+use List::AllUtils qw(pairmap pairwise);
 use Module::Load;
 use Types::Standard qw(HashRef Int);
 
@@ -23,17 +23,16 @@ use Chart::GGPlot::Aes;
 use Chart::GGPlot::Util qw(:all);
 use Chart::GGPlot::Backend::Plotly::Geom;
 use Chart::GGPlot::Backend::Plotly::Util qw(br to_rgb);
-use Chart::GGPlot::Util qw(rescale);
 
 #TODO: To test and see which value is proper.
 our $WEBGL_THRESHOLD = 2000;
 
-classmethod _split_on($class_geom_impl, $data) {
-    my $aes = $class_geom_impl->split_on;
-    return [ grep { $data->exists($_) } map { "${_}_raw" } @$aes ];
+# TODO
+classmethod _split_on($data) {
+    return [];
 }
 
-method layer_to_traces ($layer, $data, $prestats_data, $layout, $plot) {
+method layer_to_traces ($layer, $data, $layout, $plot) {
     return if ( $data->isempty );
 
     my $geom            = $layer->geom;
@@ -45,7 +44,7 @@ method layer_to_traces ($layer, $data, $prestats_data, $layout, $plot) {
     my $geom_params = $layer->geom_params;
     my $stat_params = $layer->stat_params;
     my $aes_params  = $layer->aes_params;
-    my $params = $geom_params->merge($stat_params)->merge($aes_params);
+    my $param = $geom_params->merge($stat_params)->merge($aes_params);
 
     my $coord  = $layout->coord;
 
@@ -65,10 +64,7 @@ method layer_to_traces ($layer, $data, $prestats_data, $layout, $plot) {
         Dumper( \@split_legend ) )
       if $log->is_debug;
 
-    my $split_by =
-      [ uniq( @split_legend, @{ $self->_split_on( $class_geom_impl, $data ) } )
-      ];
-
+    my $split_by = [ @split_legend, @{$self->_split_on($data)} ];
     my $split_vars = $split_by->intersect($data->names);
 
     my $hover_text_aes;     # which aes shall be displayed in hover text?
@@ -97,19 +93,14 @@ method layer_to_traces ($layer, $data, $prestats_data, $layout, $plot) {
             } @{$hover_text_aes->keys}
         )
     );
-    # throw out positional coordinates if we're hovering on fill
-    my $hover_on = $class_geom_impl->hover_on();
-    if ($hover_on eq 'fills') {
-        @hover_aes_ordered =
-          grep { not elem( $_, [qw(x xmin xmax y ymin ymax)] ) }
-          @hover_aes_ordered;
-    }
     my @hover_labels = map { $_ => $hover_text_aes->at($_) } @hover_aes_ordered;
 
     my $panel_to_traces = fun( $d, $panel_params ) {
         my $hovertext = $class_geom_impl->make_hovertext($d, \@hover_labels);
         $d->set( 'hovertext', PDL::SV->new($hovertext) );
 
+        #my $na_rm = $params->at('na_rm') // false;
+
         my @splitted_sorted;
         if ( $split_vars->length ) {
             my $fac = do {
@@ -132,13 +123,16 @@ method layer_to_traces ($layer, $data, $prestats_data, $layout, $plot) {
             push @splitted_sorted, $d;
         }
 
-        my $showlegend = @split_legend->intersect( $data->names )->length > 0;
         return @splitted_sorted->map(
             sub {
                 my ($d) = @_;
 
-                my $traces = $class_geom_impl->to_traces($d, $params, $plot);
-                for my $trace (@$traces) {
+                my $trace = $class_geom_impl->to_trace($d);
+
+                # If we need a legend, set legend info.
+                my $show_legend =
+                  @split_legend->intersect( $data->names )->length;
+                if ($show_legend) {
                     my $legend_key = join(
                         ', ',
                         map {
@@ -151,95 +145,27 @@ method layer_to_traces ($layer, $data, $prestats_data, $layout, $plot) {
                             }
                         } @split_legend
                     );
-                    $trace->name($legend_key);
-
-                    # some types like heatmap may not have below methods
-                    if ( $trace->can('showlegend') ) {
-                        $trace->legendgroup($legend_key);
-                        $trace->showlegend($showlegend);
-                    }
+                    $trace->{showlegend} = JSON::true;
+                    $trace->{name}       = $legend_key;
                 }
-                return @$traces;
-            }
+                return $trace;
+            } 
         );
     };
 
-    my $splitted_data = $data->split( $data->at('PANEL') );
-    my $splitted_prestats_data =
-      $prestats_data->split( $prestats_data->at('PANEL') );
+    my $splitted = $data->split( $data->at('PANEL') );
     return [
         pairmap {
-            my ( $panel_id, $panel_data ) = ( $a, $b );
+            my ( $panel_idx, $data ) = ( $a, $b );
 
-            my $panel_prestats_data = $splitted_prestats_data->{$panel_id};
-            my $traces = $panel_to_traces->(
-                $class_geom_impl->prepare_data(
-                    $panel_data, $panel_prestats_data, $layout,
-                    $params,     $plot
-                ),
-                $layout->panel_params->at($panel_id)
-            );
+            my $panel_params = $layout->panel_params->at($panel_idx);
+            $panel_to_traces->( $data, $panel_params );
         }
-        %$splitted_data
+        %$splitted
     ];
 }
 
 
-# create a hidden trace only for displaying colorbar
-method _colorbar_to_trace ($guide) {
-    load Chart::Plotly::Trace::Scatter;
-    load Chart::Plotly::Trace::Scatter::Marker;
-    load Chart::Plotly::Trace::Scatter::Marker::Colorbar;
-    load Chart::Plotly::Trace::Scatter::Marker::Colorbar::Title;
-
-    # do everything on a 0-1 scale
-
-    my $rng = pdl($guide->bar->at('value')->minmax);
-    my @colorscale_color = to_rgb( $guide->bar->at('color') )->list;
-    my @colorscale_value =
-      rescale( $guide->bar->at('value'), pdl( [ 0, 1 ] ), $rng )->list;
-    my @colorscale = (
-        pairwise { [ $a, $b ] }
-        @colorscale_value, @colorscale_color
-    );
-    my $ticktext = $guide->key->at('label')->unpdl;
-    my $tickvals =
-      rescale( $guide->key->at('value'), pdl( [ 0, 1 ] ), $rng )->unpdl;
-
-    my $marker = Chart::Plotly::Trace::Scatter::Marker->new(
-        color      => [ 0, 1 ],
-        colorscale => \@colorscale,
-        colorbar   => Chart::Plotly::Trace::Scatter::Marker::Colorbar->new(
-            title =>
-              Chart::Plotly::Trace::Scatter::Marker::Colorbar::Title->new(
-                text => $guide->title,
-                side => 'top'
-              ),
-            # R's default is 1.2 "lines" for "legend.key.size".
-            # We don't support the grid unit system now (maybe in future
-            # we can develop it on Graphics::Grid::Unit), now we just
-            # leave it be for plotly to use its default.
-            #thickness => 30,
-            tickmode => 'array',
-            ticktext => $ticktext,
-            tickvals => $tickvals,
-            ticklen  => 2,
-            len      => 0.5,
-        ),
-    );
-
-    return Chart::Plotly::Trace::Scatter->new(
-        x          => [0],
-        y          => [0],
-        type       => 'scatter',
-        mode       => 'markers',
-        opacity    => 0,
-        hoverinfo  => 'none',
-        showlegend => 0,
-        marker     => $marker,
-    );
-}
-
 method _to_plotly ($plot_built) {
     my $plot   = $plot_built->plot;
     my $layers = $plot->layers;
@@ -296,16 +222,10 @@ method _to_plotly ($plot_built) {
             return ($theme->at("${elname}.${xy}") // $theme->at($elname));
         };
 
-        my $axis_name;
-        my $sc;
-        if ( $plot->coordinates->DOES('Chart::GGPlot::Coord::Flip') ) {
-            my $new_xy = $xy eq 'x' ? 'y' : 'x';
-            $axis_name = "${new_xy}axis";
-            $sc = $scales->{$new_xy};
-        } else {
-            $axis_name = "${xy}axis";
-            $sc = $scales->{$xy};
-        }
+        my $sc =
+            $plot->coordinates->DOES('Chart::GGPlot::Coord::Flip')
+          ? $scales->{ $xy eq 'x' ? 'y' : 'x' }
+          : $scales->{$xy};
 
         my $axis_title = $sc->name // $labels->at($xy) // '';
 
@@ -350,7 +270,7 @@ method _to_plotly ($plot_built) {
         my $el_panel_grid = $theme_el->('panel_grid_major')
           // $theme->at('panel_grid');
 
-        $plotly_layout{$axis_name} = {
+        $plotly_layout{"${xy}axis"} = {
             range     => $range,
             zeroline  => JSON::false,
             autorange => JSON::false,
@@ -393,9 +313,7 @@ method _to_plotly ($plot_built) {
                 ) ? ( showgrid => JSON::false, )
                 : (
                     gridcolor => to_rgb( $el_panel_grid->at('color') ),
-
-                    # FIXME: fix this and use cex_to_px()
-                    gridwidth => $el_panel_grid->at('size'),
+                    gridwidth => to_rgb( $el_panel_grid->at('size') ),
                 )
             ),
         };
@@ -410,65 +328,34 @@ method _to_plotly ($plot_built) {
         }
     } # for (qw(x y))
 
-    # guides
-    my $gdefs = $plot->guides->build(
-        $plot->scales,
-        labels          => $plot->labels,
-        layers          => $layers,
-        default_mapping => $plot->mapping
-    );
-
-    # if $gdefs is empty, then no legend is displayed.
-    my $global_showlegend = !!@$gdefs;
-
-    my %seen_legendgroup;
     for my $i ( 0 .. $#$layers ) {
         my $layer = $layers->[$i];
-        my $data  = $plot_built->layer_data($i);
-        my $prestats_data  = $plot_built->layer_prestats_data($i);
+        my $data  = $plot_built->data->[$i];
 
         $log->debug( "data at layer $i:\n" . $data->string ) if $log->is_debug;
 
-        my $traces =
-          $self->layer_to_traces( $layer, $data, $prestats_data,
-            $layout, $plot );
-
-        for my $panel (@$traces) {
+        my $panels_traces =
+          $self->layer_to_traces( $layer, $data, $layout, $plot );
+        for my $panel (@$panels_traces) {
             for my $trace (@$panel) {
-                if ( $trace->can('showlegend') ) {
-                    if ( not $global_showlegend ) {
-                        $trace->showlegend(0);
-                    }
-                    elsif ( $seen_legendgroup{ $trace->legendgroup }++ ) {
-
-                        # for traces of same legend group, show legend for
-                        # only the first one of them.
-                        $trace->showlegend(0);
-                    }
-                }
-
                 $plotly->add_trace($trace);
             }
 
-            if ( List::AllUtils::any { $_->$_call_if_can('showlegend') }
-                @$panel )
-            {
+            if ( List::AllUtils::any { $_->showlegend } @$panel ) {
                 $plotly_layout{showlegend} = JSON::true;
 
                 # legend title
                 #
                 # TODO: See if plotly will officially support legend title
                 #  https://github.com/plotly/plotly.js/issues/276
-                my $br = br();
                 my $legend_titles =
-                  join( $br, map { $_->title =~ s/\n/$br/gr; } @$gdefs );
+                  join( "\n", map { $_->title } @{ $plot->guides->guides } );
 
                 my $annotations = $plotly_layout{annotations} //= [];
                 push @$annotations,
                   {
                     x         => 1.02,
                     y         => 1,
-                    align     => 'left',
                     xanchor   => 'left',
                     yanchor   => 'bottom',
                     text      => $legend_titles,
@@ -487,11 +374,6 @@ method _to_plotly ($plot_built) {
         }
     }
 
-    # Above operations already ensures for each legend group there be only
-    #  one legend item. So there is no need to keep legendgroup gap, then
-    #  it looks better to me compared with having the default gap.
-    $plotly_layout{legend} = { tracegroupgap => 0 };
-
     $plotly_layout{hovermode} = 'closest';
     $plotly_layout{barmode} = $barmode // 'relative';
     
@@ -517,18 +399,6 @@ method _to_plotly ($plot_built) {
         ];
     }
 
-    if ( $theme->at('legend_position') eq 'none' ) {
-        $plotly_layout{showlegend} = JSON::false;
-    }
-
-    # colorbar
-    my ($colorbar) =
-      grep { $_->$_DOES('Chart::GGPlot::Guide::Colorbar') } @$gdefs;
-    if ($colorbar) {
-        my $colorbar_trace = $self->_colorbar_to_trace($colorbar);
-        $plotly->add_trace($colorbar_trace);
-    }
-
     $log->debug( "plotly layout : " . Dumper( \%plotly_layout ) )
       if $log->is_debug;
 
@@ -536,7 +406,6 @@ method _to_plotly ($plot_built) {
 
     #$log->trace( "plotly html:\n" . $plotly->html ) if $log->is_trace;
 
-    $plotly->{config}{responsive} = JSON::true;
     return $plotly;
 }
 
@@ -548,39 +417,20 @@ method ggplotly ($ggplot) {
 
 method show ($ggplot, HashRef $opts={}) {
     my $plotly = $self->ggplotly($ggplot);
-    if ( $opts->{width} or $opts->{height} ) {
-        $plotly->{layout}{width}  = $opts->{width}  if ( $opts->{width} );
-        $plotly->{layout}{height} = $opts->{height} if ( $opts->{height} );
-        $plotly->{config}{responsive} = JSON::false;
-    }
-    else {
-        $plotly->{config}{responsive} = JSON::true;
-    }
     show_plot( $plotly );
 }
 
 method save ($ggplot, $filename, HashRef $opts={}) {
     my $plotly = $self->ggplotly($ggplot);
-    my %opts = %$opts;
-    
-    my $good = Chart::Plotly::Image::save_image(
+    my $good = Chart::Plotly::Image::Orca::orca(
         #<<< no perltidy
                 plot => $plotly,
                 file => $filename,
-                %opts,
+        maybe   width => $opts->{width},
+        maybe   height => $opts->{height},
         #>>>
     );
-    die "Failed to save image" unless $good;
-}
-
-method iplot ($ggplot, HashRef $opts={}) {
-    state $plugin_registered;
-    unless ($plugin_registered) {
-        IPerl->load_plugin('Chart::Plotly');
-        $plugin_registered = 1;
-    }
-
-    return $self->ggplotly($ggplot);
+    die "Failed to save image via plotly-orca" unless $good;
 }
 
 1;
@@ -597,7 +447,7 @@ Chart::GGPlot::Backend::Plotly - Plotly backend for Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 DESCRIPTION
 
@@ -615,41 +465,13 @@ Returns a L<Chart::Plotly> object.
 
     show($ggplot, HashRef $opts={})
 
-Show the plot in web browser.
-
-On POSIX systems L<Chart::Plotly> internally uses L<Browser::Open> to open
-the browser. L<Browser::Open> has a default list of browsers and tries
-them one by one. You may want to override that behavior by set env var
-C<BROWSER> to force a browser command on your system, for example, 
-
-    export BROWSER=chromium-browser
-
-Below options are supported for C<$opts>:
-
-=over 4
-
-=item *
-
-width: plot width in pixel
-
-=item *
-
-height: plot height in pixel
-
-=back
-
-If neither C<width> or C<height> is not specified, the plotly shown in browser
-will use L<fluid layout|https://plot.ly/javascript/responsive-fluid-layout/>,
-that is, figure size will be automatically resized when browser window size
-changes.
+Show the plot like in web browser.
 
 =head2 save
 
     save($ggplot, $filename, HashRef $opts={})
 
-Export the plot to a static image file. This internally uses
-L<Chart::Plotly::Image>. And to get L<Chart::Plotly::Image>
-to work, I recommend you install L<Chart::Kaleido::Plotly>.
+Export the plot to a static image file.
 
 Below options are supported for C<$opts>:
 
@@ -657,27 +479,19 @@ Below options are supported for C<$opts>:
 
 =item *
 
-width: plot width in pixel
+width
 
 =item *
 
-height: plot height in pixel
+height
 
 =back
 
-=head2 iplot
-
-    iplot($ggplot, HashRef $opts={})
-
-Generate Plotly plot for L<IPerl> in Jupyter notebook.
-
 =head1 SEE ALSO
 
 L<https://plot.ly/|Plotly>
 
-L<Chart::GGPlot::Backend>
-
-L<Chart::Plotly>, L<Chart::Plotly::Image>, L<Chart::Kaleido::Plotly>
+L<Chart::GGPlot::Backend>, L<Chart::Plotly>
 
 =head1 AUTHOR
 
