@@ -4,7 +4,7 @@ package Chart::GGPlot::Backend::Plotly::Geom;
 
 use Chart::GGPlot::Role;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use List::AllUtils qw(pairmap);
 use Types::Standard qw(ArrayRef);
@@ -12,20 +12,14 @@ use Types::Standard qw(ArrayRef);
 use Chart::GGPlot::Backend::Plotly::Util qw(br);
 
 
-classmethod split_on () { [] }
-
-
-classmethod hover_on () { 'points' }
-
-
-classmethod use_webgl ($df) {
+method use_webgl ($df) {
     my $threshold = $Chart::GGPlot::Backend::Plotly::WEBGL_THRESHOLD;
     return 0 if ( $threshold < 0 );
     return ( $df->nrow > $threshold );
 }
 
 
-requires 'to_traces';
+requires 'to_trace';
 
 
 classmethod make_hovertext ($df, ArrayRef $hover_labels) {
@@ -40,17 +34,16 @@ classmethod make_hovertext ($df, ArrayRef $hover_labels) {
                 $var = $var->expr;
             }
             my $data = $class->_hovertext_data_for_aes( $df, $aes );
-            return ( defined $data ? ( $var => $data->as_pdlsv->unpdl ) : () );
+            return ( defined $data ? ( $var => $data->as_pdlsv ) : () );
         }
     }
     @$hover_labels;
 
-    my $br = br();
-    return [
-        map {
-            join( $br, pairmap { "$a: " . $b->[$_] } @hover_assoc )
-        } ( 0 .. $df->nrow - 1 )
-    ];
+    return [ 0 .. $df->nrow - 1 ]->map(
+        sub {
+            join( br(), pairmap { "$a: " . $b->at($_) } @hover_assoc );
+        }
+    );
 }
 
 classmethod _hovertext_data_for_aes ($df, $aes) {
@@ -61,26 +54,6 @@ classmethod _hovertext_data_for_aes ($df, $aes) {
     );
 }
 
-# for preprocessing data at an early point
-classmethod prepare_data($data, $prestats_data, $layout, $params, $plot) {
-    return $data;
-}
-
-classmethod _adjust_trace_for_flip ($trace, $plot) {
-    if ( $plot->coordinates->DOES('Chart::GGPlot::Coord::Flip') ) {
-        my ( $x, $y ) = ( $trace->x, $trace->y );
-        $trace->x($y);
-        $trace->y($x);
-        $trace->$_call_if_can( 'orientation', 'h' );
-
-        my $error_x = $trace->$_call_if_can('error_x');
-        my $error_y = $trace->$_call_if_can('error_y');
-        $trace->error_x($error_y) if $error_y;
-        $trace->error_y($error_x) if $error_x;
-    }
-    return $trace;
-}
-
 1;
 
 __END__
@@ -95,23 +68,9 @@ Chart::GGPlot::Backend::Plotly::Geom - Role for geom-specific details with the P
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
-=head1 CLASS METHODS
-
-=head2 split_on
-
-    split_on()
-
-Returns an arrayref of aestheics on which continuous variables in the data
-should be splitted.
-This is necessary for some geoms, for example, polygons.
-
-=head2 hover_on
-
-    hover_on()
-
-Return value would be used for plotly trace's C<hoveron> attribute.
+=head1 METHODS
 
 =head2 use_webgl
 
@@ -125,9 +84,9 @@ The variable can be adjusted by like,
 
     $Chart::GGPlot::Backend::Plotly::WEBGL_THRESHOLD = 2000;
 
-=head2 to_traces
+=head2 to_trace
 
-    to_traces($df, $params, $plot)
+    to_trace($df, %rest)
 
 This shall be implemented by consumers of this role.
 It should return an arrayref of Chart::Plotly::Trace::X objects.  
