@@ -1,20 +1,18 @@
 package Chart::GGPlot::Backend::Plotly::Geom::Bar;
 
-# ABSTRACT: Chart::GGPlot's Plotly implementation for Geom::Bar
+# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Bar
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 with qw(Chart::GGPlot::Backend::Plotly::Geom);
 
 use Module::Load;
 
-use Chart::GGPlot::Backend::Plotly::Util qw(to_rgb pdl_to_plotly);
+use Chart::GGPlot::Backend::Plotly::Util qw(to_rgb);
 
-classmethod split_on () { [qw(fill)] }
-
-classmethod to_traces ($df, $params, $plot) {
+classmethod to_trace ($df, %rest) {
     load Chart::Plotly::Trace::Bar;
     load Chart::Plotly::Trace::Bar::Marker;
 
@@ -22,26 +20,24 @@ classmethod to_traces ($df, $params, $plot) {
     my $opacity = $df->at('alpha')->setbadtoval(1);
 
     my $marker = Chart::Plotly::Trace::Bar::Marker->new(
-        color   => pdl_to_plotly( $fill,    true ),
-        opacity => pdl_to_plotly( $opacity, true ),
+        color   => $fill->unpdl,
+        opacity => $opacity->unpdl,
     );
 
-    my $x     = $df->at('x');
-    my $base  = $df->at('ymin');
-    my $y     = $df->at('ymax') - $base;
-    my $width = $df->at('xmax') - $df->at('xmin');
+    my $x     = $df->at('x')->unpdl;
+    my $y     = ( $df->at('ymax') - $df->at('ymin') )->unpdl;
+    my $base  = $df->at('ymin')->unpdl;
+    my $width = ( $df->at('xmax') - $df->at('xmin') )->unpdl;
 
-    my $trace = Chart::Plotly::Trace::Bar->new(
-        x         => pdl_to_plotly($x),
-        y         => pdl_to_plotly($y),
-        base      => pdl_to_plotly( $base, true ),
-        width     => pdl_to_plotly( $width, true ),
+    return Chart::Plotly::Trace::Bar->new(
+        x         => $x,
+        y         => $y,
+        base      => $base,
+        width     => $width,
         marker    => $marker,
-        hovertext => pdl_to_plotly( $df->at('hovertext') ),
+        hovertext => $df->at('hovertext')->unpdl,
         hoverinfo => 'text',
-        hoveron   => $class->hover_on,
     );
-    return [ $class->_adjust_trace_for_flip($trace, $plot) ];
 }
 
 around _hovertext_data_for_aes( $orig, $class : $df, $aes ) {
@@ -64,11 +60,11 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Geom::Bar - Chart::GGPlot's Plotly implementation for Geom::Bar
+Chart::GGPlot::Backend::Plotly::Geom::Bar - Chart::GGPlot's Plotly support for Geom::Bar
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 SEE ALSO
 
