@@ -1,14 +1,14 @@
 package Chart::GGPlot::Backend::Plotly::Geom::Blank;
 
-# ABSTRACT: Chart::GGPlot's Plotly implementation for Geom::Blank
+# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Bar 
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 with qw(Chart::GGPlot::Backend::Plotly::Geom);
 
-classmethod to_traces ($df, @rest) { [] }
+classmethod to_trace ($df, %rest) { }
 
 __PACKAGE__->meta->make_immutable;
 
@@ -22,11 +22,11 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Geom::Blank - Chart::GGPlot's Plotly implementation for Geom::Blank
+Chart::GGPlot::Backend::Plotly::Geom::Blank - Chart::GGPlot's Plotly support for Geom::Bar 
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 SEE ALSO
 
