@@ -1,30 +1,30 @@
 package Chart::GGPlot::Backend::Plotly::Geom::Point;
 
-# ABSTRACT: Chart::GGPlot's Plotly implementation for Geom::Point
+# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Point
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 extends qw(Chart::GGPlot::Backend::Plotly::Geom::Path);
 
 use Module::Load;
 
-use Chart::GGPlot::Backend::Plotly::Util qw(cex_to_px to_rgb pdl_to_plotly);
+use Chart::GGPlot::Backend::Plotly::Util qw(cex_to_px to_rgb);
 use Chart::GGPlot::Util qw(ifelse);
 
 sub mode {
     return 'markers';
 }
 
-classmethod scatter_marker ($df, $params, @rest) {
+classmethod marker ($df, %rest) {
     my $color = to_rgb( $df->at('color') );
     my $fill =
       $df->exists('fill')
       ? ifelse( $df->at('fill')->isbad, $color, to_rgb( $df->at('fill') ) )
       : $color;
     my $size = cex_to_px( $df->at('size') );
-    $size->where($size < 2) .= 2;
+    $size = ifelse( $size < 2, 2, $size );
     my $opacity = $df->at('alpha')->setbadtoval(1);
     my $stroke  = cex_to_px( $df->at('stroke') );
 
@@ -38,16 +38,16 @@ classmethod scatter_marker ($df, $params, @rest) {
     load $plotly_marker_class;
 
     return $plotly_marker_class->new(
-        color => pdl_to_plotly( $fill, true ),
-        size  => pdl_to_plotly( $size, true ),
+        color => $fill->unpdl,
+        size  => $size->unpdl,
         line  => {
-            color => pdl_to_plotly( $color,  true ),
-            width => pdl_to_plotly( $stroke, true ),
+            color => $color->unpdl,
+            width => $stroke->unpdl,
         },
 
         # TODO: support scatter symbol
         symbol  => [ (0) x $df->at('size')->length ],
-        opacity => pdl_to_plotly( $opacity, true ),
+        opacity => $opacity->unpdl,
     );
 }
 
@@ -63,11 +63,11 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Geom::Point - Chart::GGPlot's Plotly implementation for Geom::Point
+Chart::GGPlot::Backend::Plotly::Geom::Point - Chart::GGPlot's Plotly support for Geom::Point
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 SEE ALSO
 
