@@ -1,33 +1,26 @@
 package Chart::GGPlot::Backend::Plotly::Util;
 
-# ABSTRACT: Utilities used by Chart::GGPlot::Backend::Plotly
+# ABSTRACT:
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
-use Data::Frame;
 use Data::Munge qw(elem);
-use List::AllUtils qw(all min max pairmap pairwise reduce);
+use Graphics::Color::RGB;
+use List::AllUtils qw(pairmap reduce);
 use PDL::Primitive qw(which);
 use Types::PDL qw(Piddle);
 use Types::Standard qw(Str);
 
 use parent qw(Exporter::Tiny);
 
-use Chart::GGPlot::Util::Scales qw(
-  csshex_to_rgb255 colorname_to_csshex
-);
-
-use constant br => '<br />';
-
 our @EXPORT_OK = qw(
-  pt_to_px cex_to_px
+  pt_to_px
+  cex_to_px
   br
   to_rgb
   group_to_NA
-  pdl_to_plotly
-  ribbon
 );
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
@@ -40,55 +33,37 @@ fun pt_to_px ($x) { $x / 72 * $dpi }
 # 0.3 is a magic number from my guess.
 fun cex_to_px ($x) { pt_to_px( 12 * $x * 0.75 * 0.3 ) }
 
-sub _rgb {
-    my ($c) = @_;
-    return 'transparent' if $c eq 'BAD';
-    return $c =~ /^#/ ? $c : colorname_to_csshex($c);
-}
-
-sub _rgba {
-    my ($c, $a) = @_;
-
-    return 'transparent' if $c eq 'BAD';
-    $c = $c =~ /^#/ ? $c : colorname_to_csshex($c);
-    return $c if $a == 1;
-
-    if ($c =~ /^#/) {
-        return sprintf(
-            "rgba(%s,%s,%s,%s)",
-            csshex_to_rgb255($c),
-            0+sprintf("%.2f", $a)   # 0+ for removing trailing zeros
-        );
-    }
-    return $c;
-}
+sub br { '<br />' }
 
 # plotly does not understands some non-rgb colors like "grey35"
-fun to_rgb ($color, $alpha=pdl(1)) {
-    state $check = Type::Params::compile((Piddle | Str), Piddle);
-    ($color, $alpha) = $check->($color, $alpha);
+fun to_rgb ($x) {
+    state $check = Type::Params::compile((Piddle | Str));
+    ($x) = $check->($x);
 
-    if ( !ref($color) ) {
-        return _rgba($color, $alpha->at(0));
+    my $rgb = sub {
+        my ($color) = @_;
+
+        if ( $color =~ /^\#/ ) {
+            return $color;
+        }
+        else {
+            try {
+                my $c = Graphics::Color::RGB->from_color_library($color);
+                return $c->as_css_hex;
+            }
+            catch {
+                return $color;
+            }
+        }
+    };
+
+    if ( !ref($x) ) {
+        return $rgb->($x);
     }
     else {
-        if ($alpha->length != $color->length and $alpha->length != 1) {
-            die "alpha must be of length 1 or the same length as x";
-        }
-        $alpha = $alpha->setbadtoval(1);
-        $alpha->where($alpha > 1) .= 1;
-        $alpha->where($alpha < 0) .= 0;
-        
-        my @color = $color->flatten;
-        my @rgba;
-        if ($alpha->uniq->length == 1 and $alpha->at(0) == 1) {
-            @rgba = map { _rgb($_) } @color;
-        } else {
-            my @alpha = $alpha->flatten;
-            @rgba = pairwise { _rgba($a, $b) } @color, @alpha;
-        }
-
-        return PDL::SV->new(\@rgba);
+        my $p = PDL::SV->new( $x->unpdl->map($rgb) );
+        $p = $p->setbadif( $x->isbad ) if $x->badflag;
+        return $p;
     }
 }
 
@@ -177,66 +152,6 @@ fun group_to_NA ($df, :$group_vars=['group'],
     );
 }
 
-# prepare from piddle to aref or value, to be send to Chart::Plotly
-fun pdl_to_plotly ($p, $allow_collapse=false) {
-    return [] if $p->length == 0;
-
-    if ( $p->badflag ) {
-        return $p->unpdl;
-    }
-
-    if ($allow_collapse) {
-        return $p->at(0) if $p->length == 1;
-
-        if ( $p->$_DOES('PDL::SV') ) {
-            my @lst  = $p->flatten;
-            my $elem = shift @lst;
-            if ( all { $_ eq $elem } @lst ) {
-                return $elem;
-            }
-        }
-        else {
-            my $elem = $p->at(0);
-            if ( ( $p == $elem )->all ) {
-                return $elem;
-            }
-        }
-    }
-
-    return $p->unpdl;
-}
-
-# Transform geom_smooth prediction confidence intervals into format plotly
-#  likes
-fun ribbon ($data) {
-    my $n        = $data->nrow;
-    my $tmp      = $data->sort( ['x'] );
-    my $tmp2     = $data->sort( ['x'], false );
-    my $not_used = $data->names->setdiff( [qw(x ymin ymax y)] );
-
-    # top-half of ribbon
-    my @others = map { $_ => $tmp->at($_) } @$not_used;
-    my $data1  = Data::Frame->new(
-        columns => [
-            x => $tmp->at('x'),
-            y => $tmp->at('ymax'),
-            @others,
-        ]
-    );
-
-    # bottom-half of ribbon
-    my @others2 = map { $_ => $tmp2->at($_) } @$not_used;
-    my $data2   = Data::Frame->new(
-        columns => [
-            x => $tmp2->at('x'),
-            y => $tmp2->at('ymin'),
-            @others2,
-        ]
-    );
-
-    return $data1->rbind($data2);
-}
-
 1;
 
 __END__
@@ -247,11 +162,11 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Util - Utilities used by Chart::GGPlot::Backend::Plotly
+Chart::GGPlot::Backend::Plotly::Util - use Chart::GGPlot::Setup qw(:base :pdl);
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 FUNCTIONS
 
