@@ -5,7 +5,7 @@ package Chart::GGPlot::Coord;
 use Chart::GGPlot::Role qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use Types::Standard qw(Bool);
 
@@ -15,10 +15,11 @@ has render_axis_h => ( is => 'rw' );
 # Renders the vertical axes.
 has render_axis_v => ( is => 'rw' );
 
-with qw(Chart::GGPlot::HasCollectibleFunctions);
+# Returns the x and y ranges
+has range => ( is => 'rw' );
 
 
-classmethod is_linear() { false; }
+has is_linear => ( is => 'ro', init_arg => undef, lazy_required => 1 );
 
 
 requires 'transform';
@@ -73,21 +74,12 @@ Chart::GGPlot::Coord - The role for coordinates
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
-=head1 DESCRIPTION
-
-This module is a Moose role for "coord".
-
-For users of Chart::GGPlot you would mostly want to look at
-L<Chart::GGPlot::Coord::Functions> instead.
-
-=head1 CLASS METHODS
+=head1 ATTRIBUTES
 
 =head2 is_linear
 
-    is_linear()
-
 Returns true if the coordinate system is linear; false otherwise.
 
 =head1 METHODS
