@@ -5,7 +5,7 @@ package Chart::GGPlot::Geom;
 use Chart::GGPlot::Role qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use Data::Frame::Util qw(guess_and_convert_to_pdl);
 use Types::Standard qw(ArrayRef CodeRef);
@@ -13,16 +13,15 @@ use Types::Standard qw(ArrayRef CodeRef);
 use Chart::GGPlot::Aes;
 use Chart::GGPlot::Util qw(:all);
 
+has optional_aes => ( is => 'ro', isa => ArrayRef, default => sub { [] } );
+
 with qw(
   Chart::GGPlot::HasRequiredAes
   Chart::GGPlot::HasDefaultAes
   Chart::GGPlot::HasNonMissingAes
   Chart::GGPlot::HasParams
-  Chart::GGPlot::HasCollectibleFunctions
 );
 
-classmethod optional_aes() { [] }
-
 method setup_data ($data, $params) { $data }
 
 # Renders a single legend key.
@@ -95,14 +94,7 @@ Chart::GGPlot::Geom - The geom role
 
 =head1 VERSION
 
-version 0.0010_01
-
-=head1 DESCRIPTION
-
-This module is a Moose role for "geom".
-
-For users of Chart::GGPlot you would mostly want to look at
-L<Chart::GGPlot::Geom::Functions> instead.
+version 0.0001
 
 =head1 AUTHOR
 
