@@ -3,10 +3,9 @@ package Chart::GGPlot::Guide;
 # ABSTRACT: Role for guide
 
 use Chart::GGPlot::Setup;
-use Function::Parameters qw(classmethod);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use parent qw(Chart::GGPlot::Params);
 
@@ -16,21 +15,11 @@ use Chart::GGPlot::Types qw(:all);
 use Chart::GGPlot::Util qw(:all);
 
 
-for my $attr (qw(title key reverse)) {
-    no strict 'refs';
-    *{$attr} = sub { $_[0]->at($attr); }
+method title() {
+    return $self->at('title');
 }
 
-# undef means "any"
-classmethod available_aes () { undef; }
-
-method train ($scale, $aesthetics=undef) {
-    return $self;
-}
-
-classmethod _reverse_df ($df) {
-    return $df->select_rows( [ reverse( 0 .. $df->nrow - 1 ) ] );
-}
+method available_aes() { undef; }
 
 1;
 
@@ -46,7 +35,7 @@ Chart::GGPlot::Guide - Role for guide
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 ATTRIBUTES
 
@@ -56,10 +45,6 @@ A string indicating a title of the guide. If an empty string, the
 title is not show. By default (C<undef>) the name of the scale
 object or the name specified in C<labs()> is used for the title.
 
-=head2 key
-
-=head2 reverse
-
 =head1 AUTHOR
 
 Stephan Loyd <sloyd@cpan.org>
