@@ -5,9 +5,9 @@ package Chart::GGPlot::Guides;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
-use List::AllUtils qw(uniq);
+use Data::Munge qw(elem);
 use Module::Load;
 
 has _guides => (is => 'ro', default => sub { {} });
@@ -23,8 +23,7 @@ my $defined_or = sub {
 };
 
 # Train each scale in scales and generate the definition of guide.
-method build ($scales, :$layers, :$labels, :$default_mapping=undef, %rest) {
-    my @gdefs;
+method build ($scales, :$labels, %rest) {
     for my $scale ($scales->scales->flatten) {
         for my $output ( $scale->aesthetics->flatten ) {
             my $guide = $self->get_guide($output) // $scale->guide;
@@ -38,42 +37,18 @@ method build ($scales, :$layers, :$labels, :$default_mapping=undef, %rest) {
             # Check the consistency of the guide and scale.
             my $guide_available_aes = $guide->available_aes;
             if ( defined $guide_available_aes
-                and $guide_available_aes->intersect( $scale->aesthetics )
-                ->length == 0 )
+                and !elem( $scale->aesthetics, $guide_available_aes ) )
             {
                 die sprintf( "Guide %s cannot be used for %s.",
-                    $guide, join( ', ', @{ $scale->aesthetics } ) );
+                    $guide, $scale->aesthetics );
             }
 
             unless (defined $guide->title) {
-                $guide->set( 'title',
-                    $scale->make_title( $scale->name // $labels->at($output) )
-                );
-            }
-
-            $guide = $guide->train($scale, $output);
-            next unless defined $guide;
-
-            if (
-                List::AllUtils::none {
-                    my $matched =
-                      $self->_matched_aes( $_, $guide, $default_mapping );
-                    my $show_legend = $_->show_legend;
-                    ( $matched->length > 0
-                          and ( not defined $show_legend or $show_legend ) )
-                }
-                @$layers
-              )
-            {
-                next;
-            }
-
-            if (defined $guide) { 
-                push @gdefs, $guide;
+                $guide->set('title', $scale->make_title( $scale->name // $labels->at($output) ));
             }
+            $self->set($output, $guide);
         }
     }
-    return \@gdefs;
 }
 
 method set($key, $guide) { $self->_guides->{$key} = $guide; }
@@ -94,23 +69,6 @@ classmethod _validate_guide ($guide) {
     }
 }
 
-classmethod _matched_aes ($layer, $guide, $defaults) {
-    my $all = [
-        uniq(
-            @{ $layer->mapping->names },
-            @{
-                ( $layer->inherit_aes ? $defaults : $layer->stat->default_aes )
-                  ->names
-            }
-        )
-    ];
-    my $geom_aes = [ @{ $layer->geom->required_aes },
-        @{ $layer->geom->default_aes->names } ];
-    my $matched = $all->intersect($geom_aes)->intersect( $guide->key->names );
-    return $matched->setdiff(
-        [ @{ $layer->geom_params->names }, @{ $layer->aes_params->names } ] );
-}
-
 1;
 
 __END__
@@ -125,7 +83,7 @@ Chart::GGPlot::Guides - The container of guides
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 METHODS
 
