@@ -5,7 +5,7 @@ package Chart::GGPlot::Layer;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use List::AllUtils qw(pairgrep pairkeys pairmap);
 use Module::Load;
@@ -49,7 +49,8 @@ has position    => ( is => 'ro', required => 1 );
 has inherit_aes => ( is => 'ro', default  => sub { false } );
 
 
-has show_legend => ( is => 'ro' );
+my $ShowLegend = ( ( Enum [qw(auto never always)] ) | AesMapping );
+has show_legend => ( is => 'ro', isa => $ShowLegend, default => 'auto' );
 
 around BUILDARGS( $orig, $class : @rest ) {
     my %params = @rest;
@@ -221,11 +222,14 @@ method map_statistic ( $data, $plot ) {
     #$aesthetics = compact($aesthetics);
 
     my $new = $aesthetics->hslice( $self->calculated_aes($aesthetics) );
+    #say Dumper($new->keys);
     return $data if ( $new->isempty );
 
     my $stat_data =
       Data::Frame->new(
         columns => [ pairmap { $a => $data->eval_tidy($b) } $new->flatten ] );
+    #say $stat_data->string;
+
     $plot->scales->add_defaults( $data, $new );
 
     # Transform the values, if the scale say it's ok
@@ -319,7 +323,7 @@ Chart::GGPlot::Layer - Chart::GGPlot layer
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 DESCRIPTION
 
@@ -375,21 +379,19 @@ Should this layer be included in the legends?
 
 =item *
 
-C<undef>, includes if any aesthetics are mapped.
+C<'auto'>, includes if any aesthetics are mapped.
 
 =item *
 
-A defined true scalar (non-Chart::GGPlot::Aes), never includes.
+C<'never'>, never includes.
 
 =item *
 
-A defined false scalar (non-Chart::GGPlot::Aes), always includes. 
+C<'always'>, always includes. 
 
 =item *
 
-A L<Chart::GGPlot::Aes> object whose values are booleans, to finely
-
-select the aesthetics to display.
+A Chart::GGPlot::Aes object, to finely select the aesthetics to display.
 
 =back
 
