@@ -5,13 +5,14 @@ package Chart::GGPlot::Layout;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use Data::Frame::Types qw(DataFrame);
-use List::AllUtils qw(pairwise reduce);
+use Data::Munge qw(elem);
+use List::AllUtils qw(pairwise);
 use PDL::Primitive qw(which);
 use Types::PDL qw(Piddle1D);
-use Types::Standard qw(ArrayRef InstanceOf HashRef Maybe);
+use Types::Standard qw(ArrayRef InstanceOf HashRef Bool);
 
 use Chart::GGPlot::Types qw(:all);
 use Chart::GGPlot::Coord::Functions qw(:all);
@@ -30,10 +31,7 @@ has [qw(coord_params facet_params)] => (
 
 has layout => ( is => 'rw', isa => DataFrame, init_arg => undef );
 
-has [qw(panel_scales_x panel_scales_y)] => (
-    is  => 'rw',
-    isa => Maybe [ArrayRef]
-);
+has [qw(panel_scales_x panel_scales_y)] => ( is => 'rw' );
 has panel_params => ( is => 'rwp', isa => ArrayRef [HashRef] );
 
 method setup (ArrayRef $data, $plot_data=Data::Frame->new()) {
@@ -223,25 +221,34 @@ classmethod scale_apply ($data, $vars, $method,
     die if ( $scale_id->nbad );
 
     my $n = $scales->length;
-    my $scale_indices = $class->_split_indices( $scale_id, $n );
+    my $scale_indices = split_indices( $scale_id, $n - 1 );
     my $scale_indices_flattened =
-      ( reduce { $a->glue( 0, $b ) } @$scale_indices )->qsorti;
+      pdl( $scale_indices->map( sub { $_->flatten } ) )->qsorti;
     return {
         $vars->map(
             fun($var)
             {
                 my $pieces = [ 0 .. $n - 1 ]->map(
                     sub {
-                        # if $method is 'train', $scale is just trained here
+                       # if $method is 'train', then $scale is just trained here
                         my $scale = $scales->at($_);
                         $scale->$method(
-                            $data->at($var)->slice( $scale_indices->[$_] ) );
+                            $data->at($var)->slice( $scale_indices->at($_) ) );
                     }
                 );
                 $pieces = $pieces->[0]->glue( 0, @$pieces[ 1 .. $#$pieces ] );
 
                 # Join pieces back together, if necessary
+
+                # Normally for a continuous scale, it gets only a pdl of
+                #  length 2. But below it would create a pdl of full length
+                #  of $data->nrow. We pad with bad values.
                 if ( $pieces->length ) {
+                    my $indices = $scale_indices_flattened->copy;
+                    $indices->slice(
+                        pdl( [ $pieces->length .. $indices->length - 1 ] ) ) .=
+                      'nan';
+                    $indices->setnantobad;
                     return ( $var => $pieces->slice($scale_indices_flattened) );
                 }
                 else {
@@ -252,14 +259,6 @@ classmethod scale_apply ($data, $vars, $method,
     };
 }
 
-# Split indices of a piddle of indices into $n groups
-# Return an arrayref of piddles.
-classmethod _split_indices (Piddle1D $indices, $n=$indices->max+1) {
-    my $indices1 = $indices->copy;
-    $indices1->where($indices1 > $n - 1) .= $n - 1;
-    return [ map { which( $indices1 == $_ ) } ( 0 .. $n - 1 ) ];
-}
-
 1;
 
 __END__
@@ -274,7 +273,7 @@ Chart::GGPlot::Layout - Layout
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 DESCRIPTION
 
