@@ -6,7 +6,7 @@ use Chart::GGPlot::Setup;
 use Function::Parameters qw(classmethod);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use List::AllUtils qw(pairgrep pairmap);
 use Storable qw(dclone);
@@ -21,13 +21,9 @@ classmethod new (@rest) {
         _hash => %params->rename( sub { $class->transform_key( $_[0] ) } )
       },
       $class;
-
-    $self->BUILD(\%params);
     return $self;
 }
 
-sub BUILD { }
-
 sub _hash { $_[0]->{_hash} }
 
 
@@ -148,7 +144,7 @@ Chart::GGPlot::Params - Collection of key-value pairs used in Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 DESCRIPTION
 
