@@ -5,14 +5,14 @@ package Chart::GGPlot::ScalesList;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
+use Data::Munge qw(elem);
 use List::AllUtils qw(pairmap pairkeys);
 use Types::Standard qw(Any ArrayRef Object);
 use Type::Params;
 use PDL::Primitive qw(which);
 
-use Chart::GGPlot::Aes::Functions qw(aes_to_scale);
 use Chart::GGPlot::Scale::Functions qw(find_scale);
 use Chart::GGPlot::Types qw(:all);
 use Chart::GGPlot::Util qw(:all);
@@ -45,7 +45,7 @@ method add ($scale) {
     my $prev_aes = $self->find( $scale->aesthetics );
     if ( $prev_aes->any ) {
         my $aes_name =
-          $self->scales->slice( [ $prev_aes->at(0) ] )->aesthetics->[0];
+          $self->scales->slice( $prev_aes->flatten )->aesthetics->[0];
         my $message =
           sprintf( "Scale for '%s' is already present. "
               . "Adding another scale for '%s', which will replace the existing scale.",
@@ -55,8 +55,7 @@ method add ($scale) {
         # Remove old scale for this aesthetic (if it exists)
         $self->scales = $self->scales->slice( !$prev_aes );
     }
-    push @{$self->scales}, $scale;
-    return;
+    $self->scales->push($scale);
 }
 
 
@@ -129,7 +128,6 @@ method transform_df ($df) {
 method add_defaults ($data, $aesthetics) {
     return if ( $aesthetics->isempty );
 
-    $aesthetics = $aesthetics->rename(\&aes_to_scale);
     my $new_aesthetics = $aesthetics->names->setdiff( $self->input );
 
     # No new aesthetics, so no new scales to add
@@ -145,7 +143,7 @@ method add_defaults ($data, $aesthetics) {
         my ( $scale_f, $func_name ) = find_scale( $aes, $datacols{$aes} );
         unless ( defined $scale_f ) {
             # some aesthetics do not have scale functions
-            if ( List::AllUtils::any { $aes eq $_ } (qw(weight width)) ) {
+            if ( elem( $aes, [qw(weight)] ) ) {
                 next;
             }
             else {
@@ -192,7 +190,7 @@ Chart::GGPlot::ScalesList - Encapsulation multiple scale objects
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 ATTRIBUTES
 
