@@ -5,15 +5,15 @@ package Chart::GGPlot::Setup;
 use 5.016;
 use warnings;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use utf8;
 use feature ':5.16';
 
 use Import::Into;
 
-use Alt::Data::Frame::ButMore 0.0053;
-use Data::Frame::Autobox ();
+use Alt::Data::Frame::ButMore;
+use Data::Frame;
 
 use Carp;
 use Data::Dumper ();
@@ -23,17 +23,29 @@ use Log::Any::Adapter;
 use Safe::Isa 1.000010 ();
 use PerlX::Maybe ();
 
+#use PerlX::Assert        ();
 use Syntax::Keyword::Try ();
 use Module::Load;
 use Moose 2.1400;
 use Moose::Role               ();
+use Moose::Autobox            ();
 use MooseX::Aliases           ();
-use MooseX::MungeHas 0.011;
+use MooseX::MungeHas          ();
+use MooseX::LazyRequire       ();
 use MooseX::StrictConstructor ();
 use boolean                   ();
 
 use List::AllUtils qw(uniq);
 
+# Add additional method to Moose::Autobox roles.
+# In this way we have similar interfaces between,
+# * arrayref and piddle
+# * hashref and aes, dataframe, etc
+for my $type (qw(Hash Array)) {
+    Moose::Autobox->mixin_additional_role(
+        uc($type) => "Data::Frame::Autobox::$type" );
+}
+
 # for debug
 if (my $trace_level = $ENV{CHART_GGPLOT_TRACE} ) {
     load Log::Dispatch;
@@ -94,7 +106,13 @@ sub _import_tag {
         Syntax::Keyword::Try->import::into($target);
         boolean->import::into($target);
 
-        Data::Frame::Autobox->import::into($target);
+        # TODO: See if I can help this issue
+        #  https://rt.cpan.org/Public/Bug/Display.html?id=123935
+        #PerlX::Assert->import::into($target);
+
+        Moose::Autobox->import::into($target);
+
+        Data::Frame->import::into($target);
     }
     elsif ( $tag eq ':class' ) {
         $class->_import_tag( $target, ':base' );
@@ -104,6 +122,7 @@ sub _import_tag {
 
         Moose->import::into($target);
         MooseX::Aliases->import::into($target);
+        MooseX::LazyRequire->import::into($target);
         MooseX::MungeHas->import::into($target);
         MooseX::StrictConstructor->import::into($target);
     }
@@ -115,6 +134,7 @@ sub _import_tag {
 
         Moose::Role->import::into($target);
         MooseX::Aliases->import::into($target);
+        MooseX::LazyRequire->import::into($target);
         MooseX::MungeHas->import::into($target);
     }
     elsif ( $tag eq ':pdl' ) {
@@ -165,7 +185,7 @@ Chart::GGPlot::Setup - Import stuffs into Chart::GGPlot classes
 
 =head1 VERSION
 
-version 0.0010_01
+version 0.0001
 
 =head1 SYNOPSIS
 
