@@ -5,7 +5,7 @@ package Chart::GGPlot::Stat;
 use Chart::GGPlot::Role qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use List::AllUtils qw(reduce pairmap);
 use Types::Standard qw(ArrayRef CodeRef Str InstanceOf Bool);
@@ -23,7 +23,6 @@ with qw(
   Chart::GGPlot::HasDefaultAes
   Chart::GGPlot::HasNonMissingAes
   Chart::GGPlot::HasParams
-  Chart::GGPlot::HasCollectibleFunctions
 );
 
 method setup_data ( $data, $params ) { $data }
@@ -59,7 +58,9 @@ method compute_layer ( $data, $params, $layout ) {
                     return $self->compute_panel( $d, $scales, $params );
                 }
                 catch {
-                    die sprintf( "Computation failed in '%s': $@", ref($self) );
+                    warn
+                      sprintf( "Computation failed in '%s': $@", ref($self) );
+                    return;
                 }
             }
         )->flatten
@@ -82,15 +83,13 @@ method compute_panel ( $data, $scales, $params ) {
             my $new_df  = $stats->{$_};
             my $old_df  = $groups->{$_};
             my $missing = $old_df->names->setdiff($new_df->names);
-            for my $colname (@$missing) {
-                $new_df->set( $colname,
-                    $old_df->at($colname)->slice( pdl( [0] ) ) );
-            }
-            $new_df;
+            $new_df->cbind(
+                $old_df->slice( [ 0 .. $new_df->nrow - 1 ], $missing ) );
         } sort { $a <=> $b } @{ $stats->keys }
     ];
 
-    return reduce { $a->rbind($b) } @$stats;
+    my $rslt = reduce { $a->rbind($b) } @$stats;
+    return $rslt;
 }
 
 method compute_group ( $data, $scales ) { ... }
@@ -117,14 +116,7 @@ Chart::GGPlot::Stat - The stat role
 
 =head1 VERSION
 
-version 0.0010_01
-
-=head1 DESCRIPTION
-
-This module is a Moose role for "stats".
-
-For users of Chart::GGPlot you would mostly want to look at
-L<Chart::GGPlot::Stat::Functions> instead.
+version 0.0001
 
 =head1 AUTHOR
 
