@@ -4,7 +4,7 @@ package Chart::GGPlot::Util::_Base;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0010_01'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use Data::Frame::Util qw(:all);
 use PDL::Ufunc qw(qsorti);
@@ -33,7 +33,7 @@ fun range_ (Piddle $p, $na_rm = false, $finite = false) {
     }
     my $p = $finite ? $p->where( $p->isfinite ) : $p;
     my $class = ref($p);
-    return $class->new( [ $p->minmax ] );
+    return $class->new( [ $p->min, $p->max ] );
 }
 
 # the R seq function is implemented by seq_n and seq_by here,
@@ -46,9 +46,7 @@ fun seq_n ( $from, $to, $n ) {
     return pdl( [$from] ) if ( $n == 1 );
 
     my $by = ( $to - $from ) / ( $n - 1 );
-    my $s = seq_by( $from, $to, $by );
-    $s->set(-1, $to);   # avoid float epsilon issues
-    return $s;
+    return seq_by( $from, $to, $by );
 }
 
 fun is_na ($p) { $p->isbad; }
@@ -73,7 +71,6 @@ fun is_null ($p) {
 
 fun sign ($p) { $p <=> 0; }
 
-
 fun match (Piddle $a, Piddle $b) {
     my $is_string =
       List::AllUtils::any { $_->$_DOES('PDL::SV') or $_->type eq 'byte' }
@@ -93,11 +90,14 @@ fun match (Piddle $a, Piddle $b) {
         else {
             my $sorted_idx = $b->qsorti;
             my $sorted     = $b->slice($sorted_idx);
-            $sorted = $sorted->where( $sorted->isgood ) if $sorted->badflag;
-            my $match = $a->vsearch_match($sorted);
-            my $idx   = $match->slice( pdl( [ 0 .. $a->length - 1 ] ) );
-            $idx = $idx->setbadif($idx < 0) if $idx->badflag;
-            return $sorted_idx->slice($idx);
+            my $match      = $a->vsearch_match($sorted);
+            my $rslt       = [ 0 .. $a->length - 1 ]->map(
+                sub {
+                    my $idx = $match->at($_);
+                    $idx < 0 ? -1 : $sorted_idx->at($idx);
+                }
+            );
+            return pdl($rslt)->setvaltobad(-1);
         }
     }
 }
@@ -119,16 +119,7 @@ Chart::GGPlot::Util::_Base - R 'base' package functions used by Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0010_01
-
-=head1 FUNCTIONS
-
-=head2 match
-
-    match(Piddle $a, $Piddle $b)
-
-Returns a vector of the positions of (first) matches of its first argument
-in its second.
+version 0.0001
 
 =head1 AUTHOR
 
